@@ -25,7 +25,7 @@
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E\N{U+060c} d/M",
+    MEd => "E\N{U+060c} d/\N{U+200f}M",
     MMM => "LLL",
     MMMEd => "E\N{U+060c} d MMM",
     MMMMEd => "E\N{U+060c} d MMMM",
@@ -69,10 +69,10 @@
   date_format_long => "d MMMM y",
   date_format_medium => "dd\N{U+200f}/MM\N{U+200f}/y",
   date_format_short => "d\N{U+200f}/M\N{U+200f}/y",
-  datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  datetime_format_full => "{1} \N{U+0641}\N{U+064a} {0}",
+  datetime_format_long => "{1} \N{U+0641}\N{U+064a} {0}",
+  datetime_format_medium => "{1}, {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "\N{U+0627}\N{U+0644}\N{U+0627}\N{U+062b}\N{U+0646}\N{U+064a}\N{U+0646}",
     "\N{U+0627}\N{U+0644}\N{U+062b}\N{U+0644}\N{U+0627}\N{U+062b}\N{U+0627}\N{U+0621}",
@@ -279,5 +279,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 37,
+  version => 38,
 }
