@@ -68,7 +68,7 @@
     "T\N{U+1ecd}\N{U+1ecd}",
     "Fra\N{U+1ecb}",
     "Sat",
-    "\N{U+1ee4}ka",
+    "S\N{U+1ecd}n",
   ],
   day_format_narrow => [
     "M",
@@ -95,7 +95,7 @@
     "T\N{U+1ecd}\N{U+1ecd}",
     "Fra\N{U+1ecb}",
     "Sat",
-    "\N{U+1ee4}ka",
+    "S\N{U+1ecd}n",
   ],
   day_stand_alone_narrow => [
     "M",
@@ -128,9 +128,9 @@
     "Af\N{U+1ecd} Kra\N{U+1ecb}st",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "%A, %d %B %Y %T %Z",
   glibc_date_format => "%d/%m/%y",
-  glibc_datetime_format => "%A, %d %B %Y %T %Z",
+  glibc_datetime_format => "%A, %d %B %Y %T",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%r",
   language => "Igbo",
@@ -219,8 +219,8 @@
     "Disemba",
   ],
   name => "Igbo Nigeria",
-  native_language => "As\N{U+1ee5}s\N{U+1ee5} Igbo",
-  native_name => "As\N{U+1ee5}s\N{U+1ee5} Igbo Na\N{U+1ecb}j\N{U+1ecb}r\N{U+1ecb}a",
+  native_language => "Igbo",
+  native_name => "Igbo Na\N{U+1ecb}j\N{U+1ecb}r\N{U+1ecb}a",
   native_script => undef,
   native_territory => "Na\N{U+1ecb}j\N{U+1ecb}r\N{U+1ecb}a",
   native_variant => undef,
@@ -267,5 +267,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 37,
+  version => 38,
 }
