@@ -12,22 +12,22 @@
     EBhms => "E h:mm:ss B",
     EHm => "E, HH:mm",
     EHms => "E, HH:mm:ss",
-    Ed => "E, d",
+    Ed => "d, E",
     Ehm => "E h:mm a",
     Ehms => "E h:mm:ss a",
     Gy => "G y '\N{U+0435}\N{U+043b}'",
     GyMMM => "G y '\N{U+0435}\N{U+043b}', MMM",
-    GyMMMEd => "E, G d MMM y '\N{U+0435}\N{U+043b}'",
-    GyMMMd => "G d MMM y '\N{U+0435}\N{U+043b}'",
+    GyMMMEd => "G y '\N{U+0435}\N{U+043b}', d MMM, E",
+    GyMMMd => "G y '\N{U+0435}\N{U+043b}', d MMM",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E, dd.MM",
+    MEd => "dd.MM, E",
     MMM => "LLL",
-    MMMEd => "E, d MMM",
+    MMMEd => "d MMM, E",
     "MMMMW-count-other" => "MMMM '\N{U+0430}\N{U+0435}\N{U+043d}\N{U+044b}\N{U+04a3}' W '\N{U+0430}\N{U+0442}\N{U+043d}\N{U+0430}\N{U+0441}\N{U+044b}'",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
@@ -41,14 +41,14 @@
     ms => "mm:ss",
     y => "y",
     yM => "MM.y",
-    yMEd => "E, dd.MM.y",
-    yMMM => "MMM, y '\N{U+0435}\N{U+043b}'",
-    yMMMEd => "E, d MMM, y '\N{U+0435}\N{U+043b}'",
-    yMMMM => "MMMM, y '\N{U+0435}\N{U+043b}'",
-    yMMMd => "d MMM, y '\N{U+0435}\N{U+043b}'",
+    yMEd => "dd.MM.y, E",
+    yMMM => "y '\N{U+0435}\N{U+043b}', MMM",
+    yMMMEd => "y '\N{U+0435}\N{U+043b}', d MMM, E",
+    yMMMM => "y '\N{U+0435}\N{U+043b}', MMMM",
+    yMMMd => "y '\N{U+0435}\N{U+043b}', d MMM",
     yMd => "dd.MM.y",
-    yQQQ => "QQQ, y '\N{U+0435}\N{U+043b}'",
-    yQQQQ => "QQQQ, y '\N{U+0435}\N{U+043b}'",
+    yQQQ => "y '\N{U+0435}\N{U+043b}', QQQ",
+    yQQQQ => "y '\N{U+0435}\N{U+043b}', QQQQ",
     "yw-count-other" => "Y '\N{U+0435}\N{U+043b}\N{U+043d}\N{U+044b}\N{U+04a3}' w '\N{U+0430}\N{U+0442}\N{U+043d}\N{U+0430}\N{U+0441}\N{U+044b}'",
   },
   code => "tt-RU",
@@ -124,10 +124,10 @@
   ],
   era_wide => [
     "\N{U+0431}\N{U+0435}\N{U+0437}\N{U+043d}\N{U+0435}\N{U+04a3} \N{U+044d}\N{U+0440}\N{U+0430}\N{U+0433}\N{U+0430} \N{U+043a}\N{U+0430}\N{U+0434}\N{U+04d9}\N{U+0440}",
-    "\N{U+0431}\N{U+0435}\N{U+0437}\N{U+043d}\N{U+0435}\N{U+04a3} \N{U+044d}\N{U+0440}\N{U+0430}",
+    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+0430}\N{U+0434}\N{U+0438}",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "%a %d %b %Y %T %Z",
   glibc_date_format => "%d.%m.%Y",
   glibc_datetime_format => "%a %d %b %Y %T",
   glibc_time_12_format => "%I:%M:%S %p",
@@ -266,5 +266,5 @@
   time_format_medium => "H:mm:ss",
   time_format_short => "H:mm",
   variant => undef,
-  version => 37,
+  version => 38,
 }
